#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.setting_controller import SettingController


class HtsTaskDisplaySettingAtt(SettingController):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     System.SettingController
                |                         HtsTaskDisplaySettingAtt

    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.hts_task_display_setting_att = com_object

    @property
    def auto_walk_act_colour(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AutoWalkActColor() As long
                | 
                |     Returns or sets the AutoWalkActColor parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: int
        """

        return self.hts_task_display_setting_att.AutoWalkActColor

    @auto_walk_act_colour.setter
    def auto_walk_act_colour(self, value: int):
        """
        :param int value:
        """

        self.hts_task_display_setting_att.AutoWalkActColor = value

    @property
    def auto_walk_act_line_type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AutoWalkActLineType() As long
                | 
                |     Returns or sets the AutoWalkActLineType parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: int
        """

        return self.hts_task_display_setting_att.AutoWalkActLineType

    @auto_walk_act_line_type.setter
    def auto_walk_act_line_type(self, value: int):
        """
        :param int value:
        """

        self.hts_task_display_setting_att.AutoWalkActLineType = value

    @property
    def auto_walk_act_line_weight(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AutoWalkActLineWeight() As long
                | 
                |     Returns or sets the AutoWalkActLineWeight parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: int
        """

        return self.hts_task_display_setting_att.AutoWalkActLineWeight

    @auto_walk_act_line_weight.setter
    def auto_walk_act_line_weight(self, value: int):
        """
        :param int value:
        """

        self.hts_task_display_setting_att.AutoWalkActLineWeight = value

    @property
    def mtp_act_colour(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property MTPActColor() As long
                | 
                |     Returns or sets the MTPActColor parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: int
        """

        return self.hts_task_display_setting_att.MTPActColor

    @mtp_act_colour.setter
    def mtp_act_colour(self, value: int):
        """
        :param int value:
        """

        self.hts_task_display_setting_att.MTPActColor = value

    @property
    def mtp_act_symbol(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property MTPActSymbol() As long
                | 
                |     Returns or sets the MTPActSymbol parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: int
        """

        return self.hts_task_display_setting_att.MTPActSymbol

    @mtp_act_symbol.setter
    def mtp_act_symbol(self, value: int):
        """
        :param int value:
        """

        self.hts_task_display_setting_att.MTPActSymbol = value

    @property
    def walk_act_colour(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property WalkActColor() As long
                | 
                |     Returns or sets the WalkActColor parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: int
        """

        return self.hts_task_display_setting_att.WalkActColor

    @walk_act_colour.setter
    def walk_act_colour(self, value: int):
        """
        :param int value:
        """

        self.hts_task_display_setting_att.WalkActColor = value

    @property
    def walk_act_line_type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property WalkActLineType() As long
                | 
                |     Returns or sets the WalkActLineType parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: int
        """

        return self.hts_task_display_setting_att.WalkActLineType

    @walk_act_line_type.setter
    def walk_act_line_type(self, value: int):
        """
        :param int value:
        """

        self.hts_task_display_setting_att.WalkActLineType = value

    @property
    def walk_act_line_weight(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property WalkActLineWeight() As long
                | 
                |     Returns or sets the WalkActLineWeight parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: int
        """

        return self.hts_task_display_setting_att.WalkActLineWeight

    @walk_act_line_weight.setter
    def walk_act_line_weight(self, value: int):
        """
        :param int value:
        """

        self.hts_task_display_setting_att.WalkActLineWeight = value

    def get_auto_walk_act_colour_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAutoWalkActColorInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the AutoWalkActColor
                |     parameter.
                |     Role:Retrieves the state of the AutoWalkActColor parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.hts_task_display_setting_att.GetAutoWalkActColorInfo(io_admin_level, io_locked)

    def get_auto_walk_act_line_type_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAutoWalkActLineTypeInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the AutoWalkActLineType
                |     parameter.
                |     Role:Retrieves the state of the AutoWalkActLineType parameter in the
                |     current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.hts_task_display_setting_att.GetAutoWalkActLineTypeInfo(io_admin_level, io_locked)

    def get_auto_walk_act_line_weight_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAutoWalkActLineWeightInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the AutoWalkActLineWeight
                |     parameter.
                |     Role:Retrieves the state of the AutoWalkActLineWeight parameter in the
                |     current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.hts_task_display_setting_att.GetAutoWalkActLineWeightInfo(io_admin_level, io_locked)

    def get_mtp_act_colour_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetMTPActColorInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the MTPActColor
                |     parameter.
                |     Role:Retrieves the state of the MTPActColor parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.hts_task_display_setting_att.GetMTPActColorInfo(io_admin_level, io_locked)

    def get_mtp_act_symbol_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetMTPActSymbolInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the MTPActSymbol
                |     parameter.
                |     Role:Retrieves the state of the MTPActSymbol parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.hts_task_display_setting_att.GetMTPActSymbolInfo(io_admin_level, io_locked)

    def get_walk_act_colour_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetWalkActColorInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the WalkActColor
                |     parameter.
                |     Role:Retrieves the state of the WalkActColor parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.hts_task_display_setting_att.GetWalkActColorInfo(io_admin_level, io_locked)

    def get_walk_act_line_type_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetWalkActLineTypeInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the WalkActLineType
                |     parameter.
                |     Role:Retrieves the state of the WalkActLineType parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.hts_task_display_setting_att.GetWalkActLineTypeInfo(io_admin_level, io_locked)

    def get_walk_act_line_weight_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetWalkActLineWeightInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the WalkActLineWeight
                |     parameter.
                |     Role:Retrieves the state of the WalkActLineWeight parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.hts_task_display_setting_att.GetWalkActLineWeightInfo(io_admin_level, io_locked)

    def set_auto_walk_act_colour_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAutoWalkActColorLock(boolean iLocked)
                | 
                |     Locks or unlocks the AutoWalkActColor parameter.
                |     Role:Locks or unlocks the AutoWalkActColor parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.hts_task_display_setting_att.SetAutoWalkActColorLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_auto_walk_act_color_lock'
        # # vba_code = """
        # # Public Function set_auto_walk_act_color_lock(hts_task_display_setting_att)
        # #     Dim iLocked (2)
        # #     hts_task_display_setting_att.SetAutoWalkActColorLock iLocked
        # #     set_auto_walk_act_color_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_auto_walk_act_line_type_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAutoWalkActLineTypeLock(boolean iLocked)
                | 
                |     Locks or unlocks the AutoWalkActLineType parameter.
                |     Role:Locks or unlocks the AutoWalkActLineType parameter if it is possible
                |     in the current administrative context. In user mode this method will always
                |     return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.hts_task_display_setting_att.SetAutoWalkActLineTypeLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_auto_walk_act_line_type_lock'
        # # vba_code = """
        # # Public Function set_auto_walk_act_line_type_lock(hts_task_display_setting_att)
        # #     Dim iLocked (2)
        # #     hts_task_display_setting_att.SetAutoWalkActLineTypeLock iLocked
        # #     set_auto_walk_act_line_type_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_auto_walk_act_line_weight_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAutoWalkActLineWeightLock(boolean iLocked)
                | 
                |     Locks or unlocks the AutoWalkActLineWeight parameter.
                |     Role:Locks or unlocks the AutoWalkActLineWeight parameter if it is possible
                |     in the current administrative context. In user mode this method will always
                |     return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.hts_task_display_setting_att.SetAutoWalkActLineWeightLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_auto_walk_act_line_weight_lock'
        # # vba_code = """
        # # Public Function set_auto_walk_act_line_weight_lock(hts_task_display_setting_att)
        # #     Dim iLocked (2)
        # #     hts_task_display_setting_att.SetAutoWalkActLineWeightLock iLocked
        # #     set_auto_walk_act_line_weight_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_mtp_act_colour_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetMTPActColorLock(boolean iLocked)
                | 
                |     Locks or unlocks the MTPActColor parameter.
                |     Role:Locks or unlocks the MTPActColor parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.hts_task_display_setting_att.SetMTPActColorLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_mtp_act_color_lock'
        # # vba_code = """
        # # Public Function set_mtp_act_color_lock(hts_task_display_setting_att)
        # #     Dim iLocked (2)
        # #     hts_task_display_setting_att.SetMTPActColorLock iLocked
        # #     set_mtp_act_color_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_mtp_act_symbol_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetMTPActSymbolLock(boolean iLocked)
                | 
                |     Locks or unlocks the MTPActSymbol parameter.
                |     Role:Locks or unlocks the MTPActSymbol parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.hts_task_display_setting_att.SetMTPActSymbolLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_mtp_act_symbol_lock'
        # # vba_code = """
        # # Public Function set_mtp_act_symbol_lock(hts_task_display_setting_att)
        # #     Dim iLocked (2)
        # #     hts_task_display_setting_att.SetMTPActSymbolLock iLocked
        # #     set_mtp_act_symbol_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_walk_act_colour_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetWalkActColorLock(boolean iLocked)
                | 
                |     Locks or unlocks the WalkActColor parameter.
                |     Role:Locks or unlocks the WalkActColor parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.hts_task_display_setting_att.SetWalkActColorLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_walk_act_color_lock'
        # # vba_code = """
        # # Public Function set_walk_act_color_lock(hts_task_display_setting_att)
        # #     Dim iLocked (2)
        # #     hts_task_display_setting_att.SetWalkActColorLock iLocked
        # #     set_walk_act_color_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_walk_act_line_type_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetWalkActLineTypeLock(boolean iLocked)
                | 
                |     Locks or unlocks the WalkActLineType parameter.
                |     Role:Locks or unlocks the WalkActLineType parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.hts_task_display_setting_att.SetWalkActLineTypeLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_walk_act_line_type_lock'
        # # vba_code = """
        # # Public Function set_walk_act_line_type_lock(hts_task_display_setting_att)
        # #     Dim iLocked (2)
        # #     hts_task_display_setting_att.SetWalkActLineTypeLock iLocked
        # #     set_walk_act_line_type_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_walk_act_line_weight_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetWalkActLineWeightLock(boolean iLocked)
                | 
                |     Locks or unlocks the WalkActLineWeight parameter.
                |     Role:Locks or unlocks the WalkActLineWeight parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.hts_task_display_setting_att.SetWalkActLineWeightLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_walk_act_line_weight_lock'
        # # vba_code = """
        # # Public Function set_walk_act_line_weight_lock(hts_task_display_setting_att)
        # #     Dim iLocked (2)
        # #     hts_task_display_setting_att.SetWalkActLineWeightLock iLocked
        # #     set_walk_act_line_weight_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'HtsTaskDisplaySettingAtt(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.arrangement_interfaces.arr_nomenclature import ArrNomenclature
from pycatia.arrangement_interfaces.arr_nomenclatures import ArrNomenclatures
from pycatia.system_interfaces.any_object import AnyObject


class ArrNomenclatureTree(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ArrNomenclatureTree
                | 
                | Represents the root User Dictionary object.
                | The user dictionary defines a hierarchy of user object type names used for
                | dynamically classifying objects. These type names are defined by the user
                | organization according to the needs of the disciplines represented in the data.
                | The user type of any object may be changed as the data becomes more precise.
                | The hierarchy of type names starts with base names, defined by the system, for
                | each type of object. The user organization may define or change the hierarchy
                | of type names under each base name.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.arr_nomenclature_tree = com_object

    @property
    def base_nomenclatures(self) -> ArrNomenclatures:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property BaseNomenclatures() As ArrNomenclatures (Read
                | Only)
                | 
                |     Returns the collection of BaseNomenclatures within this UserDictionary.

        :rtype: ArrNomenclatures
        """

        return ArrNomenclatures(self.arr_nomenclature_tree.BaseNomenclatures)

    def get_nomenclature(self, i_type_name: str) -> ArrNomenclature:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetNomenclature(CATBSTR iTypeName) As ArrNomenclature
                | 
                |     Finds a UserNomenclature by Name from this UserDictionary.

        :param str i_type_name:
        :rtype: ArrNomenclature
        """
        return ArrNomenclature(self.arr_nomenclature_tree.GetNomenclature(i_type_name))

    def __repr__(self):
        return f'ArrNomenclatureTree(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.system_interfaces.any_object import AnyObject
from pycatia.system_interfaces.collection import Collection


class AnalysisSupports(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     AnalysisSupports
                | 
                | The collection of analysis case making an Analysis.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.analysis_supports = com_object

    def item(self, i_index: int, o_positionning: AnyObject, o_pointed: AnyObject) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Item(long iIndex,
                | AnyObject oPositionning,
                | AnyObject oPointed)
                | 
                |     Returns analysis support object information using its index in the
                |     collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The numeric index is the rank in the collection. The index of the
                |             first case in the collection is 1, and the index of the last is Count.
                |             
                |         oPositionning
                |             The positionning feature is exists. 
                |         oPointed
                |             The pointed object.

        :param int i_index:
        :param AnyObject o_positionning:
        :param AnyObject o_pointed:
        :rtype: None
        """
        return self.analysis_supports.Item(i_index, o_positionning.com_object, o_pointed.com_object)

    def __repr__(self):
        return f'AnalysisSupports(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.dmaps_interfaces.activity import Activity


class MoveActionActivity(Activity):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     DMAPSInterfaces.Activity
                |                         MoveActionActivity
                | 
                | Interface representing a Move Activity inside a generic Action (Close Gun/Open
                | Gun etc).
                | 
                | Role: This interface is used to retieve/assign the value of motion
                | targets/attributes for the Move Activity.
                | The following code snippet can be used to obtain a MoveActionActivity from a
                | selected Activity
                | 
                |    Dim oSelectAct As Activity
                |    set oSelectAct = CATIA.ActiveDocument.Selection.FindObject("CATIAActivity")
                |    Dim objMoveAct As MoveActionActivity
                |    set objMoveAct = oSelectAct.GetTechnologicalObject("MoveActionActivity")
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.move_action_activity = com_object

    @property
    def home_name(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property HomeName() As CATBSTR
                | 
                |     Sets and Retreives Home Name corresponding to the activity
                |     target
                | 
                |     Returns:
                |         oHomeName Home Name stored as the target. 
                |     Parameters:
                | 
                |         iHomeName
                |             The specified Home Name as the activity target 
                | 
                |     Example:
                |
                |            Dim objMoveAct As MoveActionActivity
                |                   ......
                |            Dim  HomeName as string
                |            set HomeName=objMoveAct.HomeName
                |            HomeName  = "Home.2"
                |            objMoveAct.HomeName=HomeName

        :rtype: str
        """

        return self.move_action_activity.HomeName

    @home_name.setter
    def home_name(self, value: str):
        """
        :param str value:
        """

        self.move_action_activity.HomeName = value

    @property
    def joint_values(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property JointValues() As CATSafeArrayVariant
                | 
                |     This property returns and sets the joint values for the Move
                |     activity.
                | 
                |     Returns:
                |         oJointVal The joint values for the Move activity. 
                |     Parameters:
                | 
                |         iJointVal
                |             The specified joint values for the move activity. 
                | 
                |     Example:
                |
                |            Dim objMoveAct As MoveActionActivity
                |                   ......
                |            Dim  ListOfJointValues() 
                |            set ListOfJointValues=objMoveAct.JointValues
                |            ..
                |            For i = 0 to ubound (ListOfJointValues)
                |               ...
                |            Next
                |            objMoveAct.JointValues=ListOfJointValues

        :rtype: tuple
        """

        return self.move_action_activity.JointValues

    @joint_values.setter
    def joint_values(self, value: tuple):
        """
        :param tuple value:
        """

        self.move_action_activity.JointValues = value

    @property
    def target_type(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property TargetType() As CATBSTR (Read Only)
                | 
                |     Retreives Target Type depending on the defined target("HOME" /
                |     "JOINT")
                | 
                |     Returns:
                |         oTargetType The Target Type for the Move. 
                |     Example:
                |
                |            Dim objMoveAct As MoveActionActivity
                |                   ......
                |            Dim  TgtType As String
                |            TgtType=objMoveAct.TargetType

        :rtype: str
        """

        return self.move_action_activity.TargetType

    def __repr__(self):
        return f'MoveActionActivity(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.setting_controller import SettingController


class AnalysisPostProSettingAtt(SettingController):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     System.SettingController
                |                         AnalysisPostProSettingAtt
                | 
                | Interface to handle the Analysis & Simulation
                | "PostProcessingSetting".
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.analysis_post_pro_setting_att = com_object

    @property
    def auto_preview_mode(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AutoPreviewMode() As boolean
                | 
                |     Returns or sets the AutoPreviewMode parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: bool
        """

        return self.analysis_post_pro_setting_att.AutoPreviewMode

    @auto_preview_mode.setter
    def auto_preview_mode(self, value: bool):
        """
        :param bool value:
        """

        self.analysis_post_pro_setting_att.AutoPreviewMode = value

    @property
    def image_text_size(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ImageTextSize() As float
                | 
                |     Returns or sets the ImageTextSize parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: float
        """

        return self.analysis_post_pro_setting_att.ImageTextSize

    @image_text_size.setter
    def image_text_size(self, value: float):
        """
        :param float value:
        """

        self.analysis_post_pro_setting_att.ImageTextSize = value

    @property
    def image_text_stacking(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ImageTextStacking() As long
                | 
                |     Returns or sets the ImageTextStacking parameter.
                | 
                |     Parameters:
                | 
                |         iImageTextStacking
                |             Legal values:
                |             0 : Text stacking is Horizontal
                |             1 : Text stacking is Vertical Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: int
        """

        return self.analysis_post_pro_setting_att.ImageTextStacking

    @image_text_stacking.setter
    def image_text_stacking(self, value: int):
        """
        :param int value:
        """

        self.analysis_post_pro_setting_att.ImageTextStacking = value

    @property
    def mode_image_text_size(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ModeImageTextSize() As boolean
                | 
                |     Returns or sets the ModeImageTextSize parameter.
                | 
                |     Parameters:
                | 
                |         iModeImageTextSize
                |             Legal values:
                |             TRUE : Enables the setting of image text size
                |             FALSE: Disables the setting of image text size Ensure consistency
                |             with the C++ interface to which the work is
                |             delegated.

        :rtype: bool
        """

        return self.analysis_post_pro_setting_att.ModeImageTextSize

    @mode_image_text_size.setter
    def mode_image_text_size(self, value: bool):
        """
        :param bool value:
        """

        self.analysis_post_pro_setting_att.ModeImageTextSize = value

    @property
    def save_as_new_template_directory(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SaveAsNewTemplateDirectory() As CATBSTR
                | 
                |     Returns or sets the SaveAsNewTemplateDirectory parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: str
        """

        return self.analysis_post_pro_setting_att.SaveAsNewTemplateDirectory

    @save_as_new_template_directory.setter
    def save_as_new_template_directory(self, value: str):
        """
        :param str value:
        """

        self.analysis_post_pro_setting_att.SaveAsNewTemplateDirectory = value

    def get_auto_preview_mode_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAutoPreviewModeInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the AutoPreviewMode
                |     parameter.
                |     Role:Retrieves the state of the AutoPreviewMode parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.analysis_post_pro_setting_att.GetAutoPreviewModeInfo(io_admin_level, io_locked)

    def get_image_text_size_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetImageTextSizeInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the ImageTextSize
                |     parameter.
                |     Role:Retrieves the state of the ImageTextSize parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.analysis_post_pro_setting_att.GetImageTextSizeInfo(io_admin_level, io_locked)

    def get_image_text_stacking_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetImageTextStackingInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the ImageTextStacking
                |     parameter.
                |     Role:Retrieves the state of the ImageTextStacking parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.analysis_post_pro_setting_att.GetImageTextStackingInfo(io_admin_level, io_locked)

    def get_mode_image_text_size_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetModeImageTextSizeInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the ModeImageTextSize
                |     parameter.
                |     Role:Retrieves the state of the ModeImageTextSize parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.analysis_post_pro_setting_att.GetModeImageTextSizeInfo(io_admin_level, io_locked)

    def get_save_as_new_template_directory_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetSaveAsNewTemplateDirectoryInfo(CATBSTR
                | ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the SaveAsNewTemplateDirectory
                |     parameter.
                |     Role:Retrieves the state of the SaveAsNewTemplateDirectory parameter in the
                |     current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.analysis_post_pro_setting_att.GetSaveAsNewTemplateDirectoryInfo(io_admin_level, io_locked)

    def set_auto_preview_mode_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAutoPreviewModeLock(boolean iLocked)
                | 
                |     Locks or unlocks the AutoPreviewMode parameter.
                |     Role:Locks or unlocks the AutoPreviewMode parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.analysis_post_pro_setting_att.SetAutoPreviewModeLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_auto_preview_mode_lock'
        # # vba_code = """
        # # Public Function set_auto_preview_mode_lock(analysis_post_pro_setting_att)
        # #     Dim iLocked (2)
        # #     analysis_post_pro_setting_att.SetAutoPreviewModeLock iLocked
        # #     set_auto_preview_mode_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_image_text_size_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetImageTextSizeLock(boolean iLocked)
                | 
                |     Locks or unlocks the ImageTextSize parameter.
                |     Role:Locks or unlocks the ImageTextSize parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.analysis_post_pro_setting_att.SetImageTextSizeLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_image_text_size_lock'
        # # vba_code = """
        # # Public Function set_image_text_size_lock(analysis_post_pro_setting_att)
        # #     Dim iLocked (2)
        # #     analysis_post_pro_setting_att.SetImageTextSizeLock iLocked
        # #     set_image_text_size_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_image_text_stacking_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetImageTextStackingLock(boolean iLocked)
                | 
                |     Locks or unlocks the ImageTextStacking parameter.
                |     Role:Locks or unlocks the ImageTextStacking parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.analysis_post_pro_setting_att.SetImageTextStackingLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_image_text_stacking_lock'
        # # vba_code = """
        # # Public Function set_image_text_stacking_lock(analysis_post_pro_setting_att)
        # #     Dim iLocked (2)
        # #     analysis_post_pro_setting_att.SetImageTextStackingLock iLocked
        # #     set_image_text_stacking_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_mode_image_text_size_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetModeImageTextSizeLock(boolean iLocked)
                | 
                |     Locks or unlocks the ModeImageTextSize parameter.
                |     Role:Locks or unlocks the ModeImageTextSize parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.analysis_post_pro_setting_att.SetModeImageTextSizeLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_mode_image_text_size_lock'
        # # vba_code = """
        # # Public Function set_mode_image_text_size_lock(analysis_post_pro_setting_att)
        # #     Dim iLocked (2)
        # #     analysis_post_pro_setting_att.SetModeImageTextSizeLock iLocked
        # #     set_mode_image_text_size_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_save_as_new_template_directory_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetSaveAsNewTemplateDirectoryLock(boolean iLocked)
                | 
                |     Locks or unlocks the SaveAsNewTemplateDirectory parameter.
                |     Role:Locks or unlocks the Xxx parameter if it is possible in the current
                |     administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.analysis_post_pro_setting_att.SetSaveAsNewTemplateDirectoryLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_save_as_new_template_directory_lock'
        # # vba_code = """
        # # Public Function set_save_as_new_template_directory_lock(analysis_post_pro_setting_att)
        # #     Dim iLocked (2)
        # #     analysis_post_pro_setting_att.SetSaveAsNewTemplateDirectoryLock iLocked
        # #     set_save_as_new_template_directory_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'AnalysisPostProSettingAtt(name="{ self.name }")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.dnb_human_modeling_interfaces.swk_body_element import SWKBodyElement
from pycatia.dnb_human_modeling_interfaces.swk_center_of_gravity import SWKCenterOfGravity
from pycatia.dnb_human_modeling_interfaces.swk_segment import SWKSegment


class SWKBody(SWKBodyElement):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     DNBHumanModelingInterfaces.SWKBodyElement
                |                         SWKBody
                | 
                | This interface represents the body of the manikin.
                | It provides access to the manikin structure.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.swk_body = com_object

    @property
    def center_of_gravity(self) -> SWKCenterOfGravity:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property CenterOfGravity() As SWKCenterOfGravity (Read
                | Only)
                | 
                |     Returns the center of gravity of the current manikin.

        :rtype: SWKCenterOfGravity
        """

        return SWKCenterOfGravity(self.swk_body.CenterOfGravity)

    @property
    def center_of_gravity_displayed(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property CenterOfGravityDisplayed() As boolean
                | 
                |     Returns or sets the display of the center of gravity.

        :rtype: bool
        """

        return self.swk_body.CenterOfGravityDisplayed

    @center_of_gravity_displayed.setter
    def center_of_gravity_displayed(self, value: bool):
        """
        :param bool value:
        """

        self.swk_body.CenterOfGravityDisplayed = value

    @property
    def central_cone_displayed(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property CentralConeDisplayed() As boolean
                | 
                |     Returns or sets the central cone display of the active line of sight.

        :rtype: bool
        """

        return self.swk_body.CentralConeDisplayed

    @central_cone_displayed.setter
    def central_cone_displayed(self, value: bool):
        """
        :param bool value:
        """

        self.swk_body.CentralConeDisplayed = value

    @property
    def cone_type_bounded_cone(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ConeTypeBoundedCone() As boolean (Read Only)
                | 
                |     Returns or sets the cone type display to bounded cone for the peripheral
                |     and central cone.

        :rtype: bool
        """

        return self.swk_body.ConeTypeBoundedCone

    @property
    def cone_type_boundings(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ConeTypeBoundings() As boolean (Read Only)
                | 
                |     Returns or sets the cone type display to boundings for the peripheral and
                |     central cone.

        :rtype: bool
        """

        return self.swk_body.ConeTypeBoundings

    @property
    def cone_type_flat(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ConeTypeFlat() As boolean (Read Only)
                | 
                |     Returns or sets the cone type display to flat for the peripheral and
                |     central cone.

        :rtype: bool
        """

        return self.swk_body.ConeTypeFlat

    @property
    def cone_type_spherical(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ConeTypeSpherical() As boolean (Read Only)
                | 
                |     Returns or sets the cone type display to spherical for the peripheral and
                |     central cone.

        :rtype: bool
        """

        return self.swk_body.ConeTypeSpherical

    @property
    def ellipses_displayed(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property EllipsesDisplayed() As boolean
                | 
                |     Returns or sets the display of the manikin ellipses.

        :rtype: bool
        """

        return self.swk_body.EllipsesDisplayed

    @ellipses_displayed.setter
    def ellipses_displayed(self, value: bool):
        """
        :param bool value:
        """

        self.swk_body.EllipsesDisplayed = value

    @property
    def line_of_sight_displayed(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property LineOfSightDisplayed() As boolean
                | 
                |     Returns or sets the display of the active line of sight.

        :rtype: bool
        """

        return self.swk_body.LineOfSightDisplayed

    @line_of_sight_displayed.setter
    def line_of_sight_displayed(self, value: bool):
        """
        :param bool value:
        """

        self.swk_body.LineOfSightDisplayed = value

    @property
    def memo(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Memo() As CATBSTR
                | 
                |     Returns or records miscellaneous user-added comments about the posture.

        :rtype: str
        """

        return self.swk_body.Memo

    @memo.setter
    def memo(self, value: str):
        """
        :param str value:
        """

        self.swk_body.Memo = value

    @property
    def number_of_segments(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property NumberOfSegments() As long (Read Only)
                | 
                |     Returns the number of segments of the body.

        :rtype: int
        """

        return self.swk_body.NumberOfSegments

    @property
    def peripheral_cone_displayed(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property PeripheralConeDisplayed() As boolean
                | 
                |     Returns or sets the peripheral cone display of the active line of sight.

        :rtype: bool
        """

        return self.swk_body.PeripheralConeDisplayed

    @peripheral_cone_displayed.setter
    def peripheral_cone_displayed(self, value: bool):
        """
        :param bool value:
        """

        self.swk_body.PeripheralConeDisplayed = value

    @property
    def referential(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Referential() As CATBSTR
                | 
                |     Returns or sets the referential of the manikin. Possible values are
                |     "HPoint", "EyePoint", "LeftFoot", "RightFoot", "LowestFoot", "BetweenFeet" and
                |     "Crotch". If this manikin is a forearm model, than the possible values are
                |     either "LeftHand" or "RightHand".
                | 
                |     Example:
                | 
                |           myManikin.Body.Referential = "LowestFoot"

        :rtype: str
        """

        return self.swk_body.Referential

    @referential.setter
    def referential(self, value: str):
        """
        :param str value:
        """

        self.swk_body.Referential = value

    @property
    def referential_displayed(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ReferentialDisplayed() As boolean
                | 
                |     Returns or sets the display of the referential.

        :rtype: bool
        """

        return self.swk_body.ReferentialDisplayed

    @referential_displayed.setter
    def referential_displayed(self, value: bool):
        """
        :param bool value:
        """

        self.swk_body.ReferentialDisplayed = value

    @property
    def segments_displayed(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SegmentsDisplayed() As boolean
                | 
                |     Returns or sets the display of the segments.

        :rtype: bool
        """

        return self.swk_body.SegmentsDisplayed

    @segments_displayed.setter
    def segments_displayed(self, value: bool):
        """
        :param bool value:
        """

        self.swk_body.SegmentsDisplayed = value

    @property
    def skin_displayed(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SkinDisplayed() As boolean
                | 
                |     Returns or sets the display of the manikin surfaces (skin).

        :rtype: bool
        """

        return self.swk_body.SkinDisplayed

    @skin_displayed.setter
    def skin_displayed(self, value: bool):
        """
        :param bool value:
        """

        self.swk_body.SkinDisplayed = value

    @property
    def skin_resolution(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SkinResolution() As long
                | 
                |     Returns or sets the manikin skin resolution.
                |     The valid values range from 4 to 128.

        :rtype: int
        """

        return self.swk_body.SkinResolution

    @skin_resolution.setter
    def skin_resolution(self, value: int):
        """
        :param int value:
        """

        self.swk_body.SkinResolution = value

    def apply_position(self, pi_position_increment: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ApplyPosition(CATSafeArrayVariant piPositionIncrement)
                | 
                |     Sets a new relative manikin position.
                | 
                |     Parameters:
                | 
                |         piPositionIncrement
                |             The new position to combine with the manikin's current
                |             position.
                |             This array must contain 12 numbers, and msut be initialized using
                |             the four columns of a transformation matrix. The first nine components
                |             represent the rotation matrix.
                |             The last three components represent the translation
                |             vector.
                | 
                |     Example:
                | 
                |           This example sets the manikin to a 45-degree rotation
                |           around
                |          the x axis and at a (10, 20, 30) translation from the
                |          origin.
                |
                |          Dim myPosition(11)
                |          'Rotation (45 degrees around the x axis)
                |          myPosition(0)  = 1.000
                |          myPosition(1)  = 0
                |          myPosition(2)  = 0
                |          myPosition(3)  = 0
                |          myPosition(4)  = 0.707
                |          myPosition(5)  = 0.707
                |          myPosition(6)  = 0
                |          myPosition(7)  = -0.707
                |          myPosition(8)  = 0.707
                |          'Translation vector (10,20,30)
                |          myPosition(9)  = 10.000
                |          myPosition(10) = 20.000
                |          myPosition(11) = 30.000
                |          myManikin.Body.ApplyPosition myPosition

        :param tuple pi_position_increment:
        :rtype: None
        """
        return self.swk_body.ApplyPosition(pi_position_increment)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'apply_position'
        # # vba_code = """
        # # Public Function apply_position(swk_body)
        # #     Dim piPositionIncrement (2)
        # #     swk_body.ApplyPosition piPositionIncrement
        # #     apply_position = piPositionIncrement
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_segment(self, pi_index: int) -> SWKSegment:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetSegment(long piIndex) As SWKSegment
                | 
                |     Returns a specific segment of the body, based on an index.
                | 
                |     Parameters:
                | 
                |         piIndex
                |             The index of the segment to retrieve.
                |             The first segment is at index 0.
                |             The value of this parameter should not be higher than the number of
                |             segments on the body, minus 1.

        :param int pi_index:
        :rtype: SWKSegment
        """
        return SWKSegment(self.swk_body.GetSegment(pi_index))

    def is_balanced(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func IsBalanced() As boolean
                | 
                |     Returns:
                |         True if the manikin is well-balaned, False otherwise.
                |         Being well balanced means that the center of gravity of the
                |         manikin
                |         falls inside its basis of support, given the manikin's current posture.

        :rtype: bool
        """
        return self.swk_body.IsBalanced()

    def lock_posture(self, pi_dof_id: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub LockPosture(long piDOFId)
                | 
                |     Lock the body in the given dof

        :param int pi_dof_id:
        :rtype: None
        """
        return self.swk_body.LockPosture(pi_dof_id)

    def reset_angular_limitations(self, pi_dof_id: int, pi_reset: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ResetAngularLimitations(long piDOFId,
                | long piReset)
                | 
                |     Resets the angular limitations depending on the param piReset: 0 -> 2 OR 3
                |     OR 4 depending of the first encountered. 1 -> 2 AND 3 AND 4 2 -> Unlock the
                |     value 3 -> Restore the angular limitations if it is "No Limits" 4 -> Set back
                |     the angular limitations to their default value (50.0%)

        :param int pi_dof_id:
        :param int pi_reset:
        :rtype: None
        """
        return self.swk_body.ResetAngularLimitations(pi_dof_id, pi_reset)

    def reset_attaches(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ResetAttaches()
                | 
                |     Reset the attaches of the body.

        :rtype: None
        """
        return self.swk_body.ResetAttaches()

    def reset_ik_offsets(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ResetIKOffsets()
                | 
                |     Reset the offsets of the body.

        :rtype: None
        """
        return self.swk_body.ResetIKOffsets()

    def reset_posture(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ResetPosture()
                | 
                |     Set the manikin to the default (standing) posture.

        :rtype: None
        """
        return self.swk_body.ResetPosture()

    def reset_pref_angles(self, pi_dof_id: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ResetPrefAngles(long piDOFId)
                | 
                |     Reset the pref angles of the body.

        :param int pi_dof_id:
        :rtype: None
        """
        return self.swk_body.ResetPrefAngles(pi_dof_id)

    def set_cone_type_bounded_cone(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetConeTypeBoundedCone()

        :rtype: None
        """
        return self.swk_body.SetConeTypeBoundedCone()

    def set_cone_type_boundings(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetConeTypeBoundings()

        :rtype: None
        """
        return self.swk_body.SetConeTypeBoundings()

    def set_cone_type_flat(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetConeTypeFlat()

        :rtype: None
        """
        return self.swk_body.SetConeTypeFlat()

    def set_cone_type_spherical(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetConeTypeSpherical()

        :rtype: None
        """
        return self.swk_body.SetConeTypeSpherical()

    def set_position(self, pi_new_position: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetPosition(CATSafeArrayVariant piNewPosition)
                | 
                |     Sets a new absolute manikin position.
                | 
                |     Parameters:
                | 
                |         piNewPosition
                |             The new position to place the manikin.
                |             This array must contain 12 numbers, and msut be initialized using
                |             the four columns of a transformation matrix. The first nine components
                |             represent the rotation matrix.
                |             The last three components represent the translation
                |             vector.
                | 
                |     Example:
                | 
                |           This example sets the manikin to a 45-degree rotation
                |           around
                |          the x axis and at a (10, 20, 30) translation from the
                |          origin.
                |
                |          Dim myPosition(11)
                |          'Rotation (45 degrees around the x axis)
                |          myPosition(0)  = 1.000
                |          myPosition(1)  = 0
                |          myPosition(2)  = 0
                |          myPosition(3)  = 0
                |          myPosition(4)  = 0.707
                |          myPosition(5)  = 0.707
                |          myPosition(6)  = 0
                |          myPosition(7)  = -0.707
                |          myPosition(8)  = 0.707
                |          'Translation vector (10,20,30)
                |          myPosition(9)  = 10.000
                |          myPosition(10) = 20.000
                |          myPosition(11) = 30.000
                |          myManikin.Body.SetPosition myPosition

        :param tuple pi_new_position:
        :rtype: None
        """
        return self.swk_body.SetPosition(pi_new_position)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_position'
        # # vba_code = """
        # # Public Function set_position(swk_body)
        # #     Dim piNewPosition (2)
        # #     swk_body.SetPosition piNewPosition
        # #     set_position = piNewPosition
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_posture(self, pi_posture_spec: int, pi_keep_referential: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetPosture(SWKPostureSpec piPostureSpec,
                | boolean piKeepReferential)
                | 
                |     Set the manikin to a specific predefined posture.
                |     Predefined postures include "Stand", "Sit", "Reach"
                |     and "Kneel".
                | 
                |     See also:
                |         SWKPostureSpec 
                |     Parameters:
                | 
                |         piKeepReferential
                |             keeps the referential after the change of the
                |             posture

        :param int pi_posture_spec: enum swk_posture_spec
        :param bool pi_keep_referential:
        :rtype: None
        """
        return self.swk_body.SetPosture(pi_posture_spec, pi_keep_referential)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_posture'
        # # vba_code = """
        # # Public Function set_posture(swk_body)
        # #     Dim piPostureSpec (2)
        # #     swk_body.SetPosture piPostureSpec
        # #     set_posture = piPostureSpec
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_to_best_posture(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetToBestPosture()
                | 
                |     Set the manikin to the posture that will provide it its maximum score.
                |     When the manikin is in that posture, then the output of property
                |     PosturalScore will be the same as that of property MaxPosturalScore.

        :rtype: None
        """
        return self.swk_body.SetToBestPosture()

    def swap_angular_limitations(self, pi_dof_id: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SwapAngularLimitations(long piDOFId)
                | 
                |     Swap the angular limitations of the body.

        :param int pi_dof_id:
        :rtype: None
        """
        return self.swk_body.SwapAngularLimitations(pi_dof_id)

    def swap_posture(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SwapPosture()
                | 
                |     Swap the posture with the equivalent segment, on the other side of the
                |     manikin. For instance, the right leg takes the posture of the left leg, and
                |     vice versa.

        :rtype: None
        """
        return self.swk_body.SwapPosture()

    def swap_pref_angles(self, pi_dof_id: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SwapPrefAngles(long piDOFId)
                | 
                |     Swap the preferred angles of the body.

        :param int pi_dof_id:
        :rtype: None
        """
        return self.swk_body.SwapPrefAngles(pi_dof_id)

    def __repr__(self):
        return f'SWKBody(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-09 09:53:18.676780

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.setting_controller import SettingController


class SettingRepository(SettingController):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     System.SettingController
                |                         SettingRepository
                | 
                | Represents the base object to handle the parameters of a
                | setting
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.setting_repository = com_object

    def get_attr(self, i_attr_name):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780))
                | o Func GetAttr(CATBSTR iAttrName) As CATVariant
                | 
                |     Retieves a attribute.
                | 
                |     Parameters:
                | 
                |         iAttrName
                |             the attribute name 
                |         oAttr
                |             a CATVariant 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param str i_attr_name:
        :return: CATVariant
        """
        return self.setting_repository.GetAttr(i_attr_name)

    def get_attr_array(self, i_attr_name):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780))
                | o Func GetAttrArray(CATBSTR iAttrName) As
                | CATSafeArrayVariant
                | 
                |     Retieves a attribute of type array
                | 
                |     Parameters:
                | 
                |         iAttrName
                |             the attribute name 
                |         oArray
                |             a CATSafeArrayVariant 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param str i_attr_name:
        :return: tuple
        """
        return tuple(self.setting_repository.GetAttrArray(i_attr_name))

    def get_attr_info(self, i_attr_name, admin_level, locked, o_modified):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780))
                | o Sub GetAttrInfo(CATBSTR iAttrName,
                | CATBSTR AdminLevel,
                | CATBSTR Locked,
                | boolean oModified)
                | 
                |     Retrieves environment informations for the given
                |     attribute.
                |     Role: This information defines the state of the setting parameter and is
                |     made up of:
                | 
                |         The administration level that sets the current value or the value used
                |         to reset it
                |         The administration level that has locked the setting
                |         parameter.
                |         A flag to indicate whether the setting parameter was
                |         modified.
                | 
                |     Parameters:
                | 
                |         iAttrName
                |             [in] the attribute name. 
                |         ioAdminLevel
                |             [inout] The administration level that defines the value used when
                |             resetting the setting parameter.
                | 
                |             Legal values:
                | 
                |                 Default value if the setting parameter has never been
                |                 explicitly set in the administration
                |                 concatenation.
                |                 Set at Admin Level n if the setting parameter has been
                |                 administered,
                |                 where n is an integer starting from 0 representing the rank of
                |                 the administration level.
                | 
                |         ioLocked
                |             [inout] A character string to indicate whether the parameter is
                |             locked and the level of administration where the locking has been
                |             proceeded.
                |             Legal values:
                | 
                |                 Locked at Admin Level n if the setting parameter is locked by
                |                 then administration level n,
                |                 where n is an integer starting from 0. The setting parameter
                |                 can not be modified at the current level.
                |                 Locked if the setting parameter is locked by the current
                |                 administration level. Only an admistrator can get this
                |                 value.
                |                 Unlocked if the setting parameter is not
                |                 locked
                | 
                |         oModified
                |             [out] True to indicate that the setting parameter value has been
                |             explicitely modified at the current administrator or user level. This is only
                |             possible with unlocked parameters. False means that it inherits the
                |             administered value. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param str i_attr_name:
        :param str admin_level:
        :param str locked:
        :param bool o_modified:
        :return: None
        """
        return self.setting_repository.GetAttrInfo(i_attr_name, admin_level, locked, o_modified)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_attr_info'
        # # vba_code = """
        # # Public Function get_attr_info(setting_repository)
        # #     Dim iAttrName (2)
        # #     setting_repository.GetAttrInfo iAttrName
        # #     get_attr_info = iAttrName
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def put_attr(self, i_attr_name, i_attr):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780))
                | o Sub PutAttr(CATBSTR iAttrName,
                | CATVariant iAttr)
                | 
                |     Sets an attribute of type array.
                | 
                |     Parameters:
                | 
                |         iAttrName
                |             the attribute name 
                |         iArray
                |             a CATSafeArrayVariant. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param str i_attr_name:
        :param cat_variant i_attr:
        :return: None
        """
        return self.setting_repository.PutAttr(i_attr_name, i_attr)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'put_attr'
        # # vba_code = """
        # # Public Function put_attr(setting_repository)
        # #     Dim iAttrName (2)
        # #     setting_repository.PutAttr iAttrName
        # #     put_attr = iAttrName
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def put_attr_array(self, i_attr_name, i_array):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780))
                | o Sub PutAttrArray(CATBSTR iAttrName,
                | CATSafeArrayVariant iArray)
                | 
                |     Sets an attribute of type array.
                | 
                |     Parameters:
                | 
                |         iAttrName
                |             the attribute name 
                |         iArray
                |             a CATSafeArrayVariant. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param str i_attr_name:
        :param tuple i_array:
        :return: None
        """
        return self.setting_repository.PutAttrArray(i_attr_name, i_array)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'put_attr_array'
        # # vba_code = """
        # # Public Function put_attr_array(setting_repository)
        # #     Dim iAttrName (2)
        # #     setting_repository.PutAttrArray iAttrName
        # #     put_attr_array = iAttrName
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_attr_lock(self, i_attr_name, i_locked):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780))
                | o Sub SetAttrLock(CATBSTR iAttrName,
                | boolean iLocked)
                | 
                |     Locks or unlocks an attribute.
                |     Role: Locking a setting attribute prevents the end user, or the
                |     administrators below the current one, from changing the setting parameter
                |     value. Locking or unlocking the attribute setting parameter is an administrator
                |     task and is possible when running a session in the administration mode
                |     only.
                | 
                |     Parameters:
                | 
                |         iAttrName
                |             [in] the attribute name. 
                |         iLocked
                |             [in] A flag to indicate whether the attribute setting parameter
                |             should be locked.
                |             Legal values: True to lock, and False to unlock.

        :param str i_attr_name:
        :param bool i_locked:
        :return: None
        """
        return self.setting_repository.SetAttrLock(i_attr_name, i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_attr_lock'
        # # vba_code = """
        # # Public Function set_attr_lock(setting_repository)
        # #     Dim iAttrName (2)
        # #     setting_repository.SetAttrLock iAttrName
        # #     set_attr_lock = iAttrName
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'SettingRepository(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.viewer import Viewer
from pycatia.in_interfaces.viewpoint_2d import Viewpoint2D


class Viewer2D(Viewer):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     InfInterfaces.Viewer
                |                         Viewer2D
                | 
                | Represents a 2D viewer.
                | The 2D viewer aggregates a 2D viewpoint to display a 2D scene.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.viewer_2d = com_object

    @property
    def viewpoint_2d(self) -> Viewpoint2D:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Viewpoint2D() As Viewpoint2D
                | 
                |     Returns or sets the 2D viewpoint of a 2D viewer.
                | 
                |     Example:
                |         This example retrieves the Nice2DViewpoint 2D viewpoint from the
                |         My2DViewer 2D viewer.
                | 
                |          Dim Nice2DViewpoint As Viewpoint2D
                |          Set Nice2DViewpoint = My2DViewer.Viewpoint2D

        :rtype: Viewpoint2D
        """

        return Viewpoint2D(self.viewer_2d.Viewpoint2D)

    @viewpoint_2d.setter
    def viewpoint_2d(self, value: Viewpoint2D):
        """
        :param Viewpoint2D value:
        """

        self.viewer_2d.Viewpoint2D = value

    def __repr__(self):
        return f'Viewer2D(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.eno_cd5_interfaces.cd5_engine import CD5Engine
from pycatia.eno_cd5_interfaces.cd5_save_operation import CD5SaveOperation


class CD5EngineV6R2014x(CD5Engine):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ENOCD5Interfaces.CD5Engine
                |                         CD5EngineV6R2014x
                | 
                | Represents the ENOVIA V6 Integration Engine, that is to say the entry point to
                | the CATIA/ENOVIA V6 Integration.
                | 
                | It allows end user to realize ENOVIA V6 Integration operations such as
                | Connection, Disconnection, Open, Save...
                | Note that all operations performed from this interface are the same as
                | operations available in the ENOVIA V6 menu in CATIA, unless most of them are
                | executed without panel.
                | 
                | Example:
                | 
                |       The following example indicates how to retrieve the ENOVIA V6 Integration
                |       Engine.
                |
                |      Dim oCD5Engine As CD5EngineV6R2014x
                |      Set oCD5Engine = CATIA.GetItem("CD5EngineV6R2014x")
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.cd5_engine_v6_r2014x = com_object

    def create_save_operation(self, i_scope: int) -> CD5SaveOperation:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func CreateSaveOperation(CD5SaveOperation_Scope iScope) As
                | CD5SaveOperation
                |
                |     Creates the basic Save Operation object. It requires ENOVIA V6
                |     connection.
                |
                |     Parameters:
                |
                |         iScope
                |             The scope of the Save Operation.
                |
                |     Returns:
                |         The created Save Operation.
                |     Throws:
                |
                |         -1697450280 : CATIA is not connected to ENOVIA V6.
                |
                |     Example:
                |
                |           The following example creates a Save Operation with the whole session
                |           as scope on CD5Engine oCD5Engine:
                |
                |          Dim SaveOperation As CD5SaveOperation
                |          Set SaveOperation = oCD5Engine.CreateSaveOperation(CD5SaveOperation_Session)

        :param int i_scope: enum cd5_save_operation_scope
        :rtype: CD5SaveOperation
        """
        return CD5SaveOperation(self.cd5_engine_v6_r2014x.CreateSaveOperation(i_scope).com_object)

    def generate_autoname(self, i_autoname_series: str, i_count: int) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GenerateAutoname(CATBSTR iAutonameSeries,
                | short iCount) As CATSafeArrayVariant
                |
                |     Generates and gets the Autonames for the given series. It requires ENOVIA
                |     V6 connection.
                |
                |     Parameters:
                |
                |         iAutonameSeries
                |             The Autoname Series for which we want to generate Autonames.
                |
                |         iCount
                |             The number of Autonames to be generated.
                |
                |     Returns:
                |         The array of generated Autonames.
                |     Throws:
                |
                |         -1697450280 : CATIA is not connected to ENOVIA V6.
                |
                |     Example:
                |
                |           The following example generates and gets 1 Autoname for series "A
                |           Size":
                |
                |          Dim Autoname As CATBSTR
                |          Autoname = oCD5Engine.GenerateAutoname("A Size", 1)(0)

        :param str i_autoname_series:
        :param int i_count:
        :rtype: tuple
        """
        return self.cd5_engine_v6_r2014x.GenerateAutoname(i_autoname_series, i_count)

    def get_autoname_series(self, i_type: str) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAutonameSeries(CATBSTR iType) As
                | CATSafeArrayVariant
                |
                |     Gets the Autoname Series for an input type. It requires ENOVIA V6
                |     connection.
                |
                |     Parameters:
                |
                |         iType
                |             The ENOVIA type of the Object ("CATIA Embedded Component"...).
                |
                |
                |     Returns:
                |         The array of Autoname Series.
                |     Throws:
                |
                |         -1697450280 : CATIA is not connected to ENOVIA V6.
                |
                |     Example:
                |
                |           The following example gets autoname series for CATIA Embedded
                |           Component:
                |
                |          Dim AutonameSeries As CATSafeArrayVariant
                |          AutonameSeries = oCD5Engine.GetAutonameSeries("CATIA Embedded Component")

        :param str i_type:
        :rtype: tuple
        """
        return self.cd5_engine_v6_r2014x.GetAutonameSeries(i_type)

    def __repr__(self):
        return f'CD5EngineV6R2014x(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class RenderingLight(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     RenderingLight
                | 
                | Represents a Rendering Light object.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.rendering_light = com_object

    @property
    def active_status(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ActiveStatus() As short
                | 
                |     Returns or sets the light active status.
                |     A light illuminates only when it is active. The active status can
                |     be:
                |     1: light is on
                |     0: light is off

        :rtype: int
        """

        return self.rendering_light.ActiveStatus

    @active_status.setter
    def active_status(self, value: int):
        """
        :param int value:
        """

        self.rendering_light.ActiveStatus = value

    @property
    def ambient(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Ambient() As double
                | 
                |     Returns or sets the light ambient intensity of a light.

        :rtype: float
        """

        return self.rendering_light.Ambient

    @ambient.setter
    def ambient(self, value: float):
        """
        :param float value:
        """

        self.rendering_light.Ambient = value

    @property
    def angle(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Angle() As double
                | 
                |     Returns or sets the light angle of a spot light.
                |     The angle ranges from 0. (directional light) to 360. (point light).

        :rtype: float
        """

        return self.rendering_light.Angle

    @angle.setter
    def angle(self, value: float):
        """
        :param float value:
        """

        self.rendering_light.Angle = value

    @property
    def area_samples_u(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AreaSamplesU() As short
                | 
                |     Changes the number of samples taken in U direction of the area source.

        :rtype: int
        """

        return self.rendering_light.AreaSamplesU

    @area_samples_u.setter
    def area_samples_u(self, value: int):
        """
        :param int value:
        """

        self.rendering_light.AreaSamplesU = value

    @property
    def area_samples_v(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AreaSamplesV() As short
                | 
                |     Changes the number of samples taken in V direction of the area source.

        :rtype: int
        """

        return self.rendering_light.AreaSamplesV

    @area_samples_v.setter
    def area_samples_v(self, value: int):
        """
        :param int value:
        """

        self.rendering_light.AreaSamplesV = value

    @property
    def area_status(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AreaStatus() As short
                | 
                |     Returns or sets the light area visibility status.
                |     The area visibility status can be:
                |     1: light area is rendered
                |     0: light area is not rendered

        :rtype: int
        """

        return self.rendering_light.AreaStatus

    @area_status.setter
    def area_status(self, value: int):
        """
        :param int value:
        """

        self.rendering_light.AreaStatus = value

    @property
    def attenuation_angle_ratio(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AttenuationAngleRatio() As double
                | 
                |     Returns or sets the light attenuation angle ratio.
                |     It represents the fraction of the light angle where the illumination starts
                |     to attenuate.
                |     The ratio ranges from 0. (attenuation starts when angle is null) to 1.
                |     (attenuation starts when angle is maximum = no angle attenuation).

        :rtype: float
        """

        return self.rendering_light.AttenuationAngleRatio

    @attenuation_angle_ratio.setter
    def attenuation_angle_ratio(self, value: float):
        """
        :param float value:
        """

        self.rendering_light.AttenuationAngleRatio = value

    @property
    def attenuation_start_ratio(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AttenuationStartRatio() As double
                | 
                |     Returns or sets the light attenuation start ratio.
                |     It represents the fraction of the end distance where the light intensity
                |     starts to attenuate.
                |     The ratio ranges from 0. (attenuation starts at the origin) to 1.
                |     (attenuation starts at the end distance = no attenuation).

        :rtype: float
        """

        return self.rendering_light.AttenuationStartRatio

    @attenuation_start_ratio.setter
    def attenuation_start_ratio(self, value: float):
        """
        :param float value:
        """

        self.rendering_light.AttenuationStartRatio = value

    @property
    def caustic_photons_number(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property CausticPhotonsNumber() As long
                | 
                |     Changes the maximum number of caustic photons to emit from the light
                |     source.

        :rtype: int
        """

        return self.rendering_light.CausticPhotonsNumber

    @caustic_photons_number.setter
    def caustic_photons_number(self, value: int):
        """
        :param int value:
        """

        self.rendering_light.CausticPhotonsNumber = value

    @property
    def cylinder_light_height(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property CylinderLightHeight() As double
                | 
                |     Returns or sets the cylinder light area radius.

        :rtype: float
        """

        return self.rendering_light.CylinderLightHeight

    @cylinder_light_height.setter
    def cylinder_light_height(self, value: float):
        """
        :param float value:
        """

        self.rendering_light.CylinderLightHeight = value

    @property
    def cylinder_light_radius(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property CylinderLightRadius() As double
                | 
                |     Returns or sets the cylinder light area radius.

        :rtype: float
        """

        return self.rendering_light.CylinderLightRadius

    @cylinder_light_radius.setter
    def cylinder_light_radius(self, value: float):
        """
        :param float value:
        """

        self.rendering_light.CylinderLightRadius = value

    @property
    def diffuse(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Diffuse() As double
                | 
                |     Returns or sets the light diffuse intensity of a light.

        :rtype: float
        """

        return self.rendering_light.Diffuse

    @diffuse.setter
    def diffuse(self, value: float):
        """
        :param float value:
        """

        self.rendering_light.Diffuse = value

    @property
    def disk_light_radius(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property DiskLightRadius() As double
                | 
                |     Returns or sets the disk light area radius.

        :rtype: float
        """

        return self.rendering_light.DiskLightRadius

    @disk_light_radius.setter
    def disk_light_radius(self, value: float):
        """
        :param float value:
        """

        self.rendering_light.DiskLightRadius = value

    @property
    def end_distance(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property EndDistance() As double
                | 
                |     Returns or sets the light maximum distance of
                |     illumination.
                |     The light illuminates from its origin to its end distance. Objects farther
                |     than this distance are not affected by the light.

        :rtype: float
        """

        return self.rendering_light.EndDistance

    @end_distance.setter
    def end_distance(self, value: float):
        """
        :param float value:
        """

        self.rendering_light.EndDistance = value

    @property
    def energy_factor(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property EnergyFactor() As double
                | 
                |     Changes the factor for indirect illumination energy.

        :rtype: float
        """

        return self.rendering_light.EnergyFactor

    @energy_factor.setter
    def energy_factor(self, value: float):
        """
        :param float value:
        """

        self.rendering_light.EnergyFactor = value

    @property
    def falloff_exponent(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property FalloffExponent() As short
                | 
                |     Changes the light falloff exponent. Exponent value can be 0, 1 or
                |     2.
                |     An exponent of 0 means that the light energy does not fall off with distance.
                |     An exponent of 1 means that the light energy fall off is linear.
                |     An exponent of 2 is physically correct.

        :rtype: int
        """

        return self.rendering_light.FalloffExponent

    @falloff_exponent.setter
    def falloff_exponent(self, value: int):
        """
        :param int value:
        """

        self.rendering_light.FalloffExponent = value

    @property
    def global_photons_number(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property GlobalPhotonsNumber() As long
                | 
                |     Changes the maximum number of global illumination photons to emit from the
                |     light source.

        :rtype: int
        """

        return self.rendering_light.GlobalPhotonsNumber

    @global_photons_number.setter
    def global_photons_number(self, value: int):
        """
        :param int value:
        """

        self.rendering_light.GlobalPhotonsNumber = value

    @property
    def hardware_shadow_smoothing(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property HardwareShadowSmoothing() As short
                | 
                |     Returns or sets the light shadow smoothing.
                |     It is an integer in the scale 0 to 10 It represents the cleanliness of the
                |     shadow limits

        :rtype: int
        """

        return self.rendering_light.HardwareShadowSmoothing

    @hardware_shadow_smoothing.setter
    def hardware_shadow_smoothing(self, value: int):
        """
        :param int value:
        """

        self.rendering_light.HardwareShadowSmoothing = value

    @property
    def hardware_shadow_status(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property HardwareShadowStatus() As short
                | 
                |     Returns or sets the light shadow status on environment.
                |     The shadow status can be:
                |     1: light casts shadows on environment
                |     0: light does not cast shadows on environment
                | 
                |     The shadow status on environmemt can be activate only with a directional
                |     light

        :rtype: int
        """

        return self.rendering_light.HardwareShadowStatus

    @hardware_shadow_status.setter
    def hardware_shadow_status(self, value: int):
        """
        :param int value:
        """

        self.rendering_light.HardwareShadowStatus = value

    @property
    def hardware_shadow_transparency(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property HardwareShadowTransparency() As double
                | 
                |     Returns or sets the light shadow transparency.
                |     It is a float in the scale 0.0(no transparency) to 1.0 (full transparency)

        :rtype: float
        """

        return self.rendering_light.HardwareShadowTransparency

    @hardware_shadow_transparency.setter
    def hardware_shadow_transparency(self, value: float):
        """
        :param float value:
        """

        self.rendering_light.HardwareShadowTransparency = value

    @property
    def illumination_status(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property IlluminationStatus() As short
                | 
                |     Changes the indirect illumination status.
                |     The indirect illumination status can be:
                |     1: indirect illumination is enabled
                |     0: indirect illumination is disabled

        :rtype: int
        """

        return self.rendering_light.IlluminationStatus

    @illumination_status.setter
    def illumination_status(self, value: int):
        """
        :param int value:
        """

        self.rendering_light.IlluminationStatus = value

    @property
    def intensity(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Intensity() As double
                | 
                |     Returns or sets the light intensity of a light.

        :rtype: float
        """

        return self.rendering_light.Intensity

    @intensity.setter
    def intensity(self, value: float):
        """
        :param float value:
        """

        self.rendering_light.Intensity = value

    @property
    def light_area_type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property LightAreaType() As short
                | 
                |     Returns or sets the light area type.
                | 
                |         Possible area light types are:
                |         1: CATNone
                |         2: CATRectangle
                |         3: CATDisk
                |         4: CATSphere
                |         5: CATCylinder

        :rtype: int
        """

        return self.rendering_light.LightAreaType

    @light_area_type.setter
    def light_area_type(self, value: int):
        """
        :param int value:
        """

        self.rendering_light.LightAreaType = value

    @property
    def mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Mode() As short
                | 
                |     Returns or sets the light mode.
                | 
                |         Possible light modes are:
                |         1: Light is linked to the viewpoint
                |         2: Light is linked to the model

        :rtype: int
        """

        return self.rendering_light.Mode

    @mode.setter
    def mode(self, value: int):
        """
        :param int value:
        """

        self.rendering_light.Mode = value

    @property
    def rectangle_light_length(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property RectangleLightLength() As double
                | 
                |     Returns or sets the light area length.

        :rtype: float
        """

        return self.rendering_light.RectangleLightLength

    @rectangle_light_length.setter
    def rectangle_light_length(self, value: float):
        """
        :param float value:
        """

        self.rendering_light.RectangleLightLength = value

    @property
    def rectangle_light_width(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property RectangleLightWidth() As double
                | 
                |     Returns or sets the light area width.

        :rtype: float
        """

        return self.rendering_light.RectangleLightWidth

    @rectangle_light_width.setter
    def rectangle_light_width(self, value: float):
        """
        :param float value:
        """

        self.rendering_light.RectangleLightWidth = value

    @property
    def shadow_fitting_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ShadowFittingMode() As short
                | 
                |     Returns or sets the light shadow fitting mode.
                |     The shadow fitting mode can be:
                |     0: Standard
                |     1: Good

        :rtype: int
        """

        return self.rendering_light.ShadowFittingMode

    @shadow_fitting_mode.setter
    def shadow_fitting_mode(self, value: int):
        """
        :param int value:
        """

        self.rendering_light.ShadowFittingMode = value

    @property
    def shadow_map_size(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ShadowMapSize() As short
                | 
                |     Returns or sets the light shadow map size.
                |     The shadow map size can be:
                |     0: Small (512)
                |     1: Medium (1024)
                |     2: Large (2048)

        :rtype: int
        """

        return self.rendering_light.ShadowMapSize

    @shadow_map_size.setter
    def shadow_map_size(self, value: int):
        """
        :param int value:
        """

        self.rendering_light.ShadowMapSize = value

    @property
    def shadow_object_status(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ShadowObjectStatus() As short
                | 
                |     Returns or sets the light shadow status on objet.
                |     The shadow status can be:
                |     1: light casts shadows on objet
                |     0: light does not cast shadows on objet
                | 
                |     The shadow status on object can be activate only with a spot light

        :rtype: int
        """

        return self.rendering_light.ShadowObjectStatus

    @shadow_object_status.setter
    def shadow_object_status(self, value: int):
        """
        :param int value:
        """

        self.rendering_light.ShadowObjectStatus = value

    @property
    def shadow_status(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ShadowStatus() As short
                | 
                |     Returns or sets the light shadow status.
                |     The shadow status can be:
                |     1: light casts shadows
                |     0: light does not cast shadows

        :rtype: int
        """

        return self.rendering_light.ShadowStatus

    @shadow_status.setter
    def shadow_status(self, value: int):
        """
        :param int value:
        """

        self.rendering_light.ShadowStatus = value

    @property
    def specular(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Specular() As double
                | 
                |     Returns or sets the light specular intensity of a light.

        :rtype: float
        """

        return self.rendering_light.Specular

    @specular.setter
    def specular(self, value: float):
        """
        :param float value:
        """

        self.rendering_light.Specular = value

    @property
    def sphere_light_radius(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SphereLightRadius() As double
                | 
                |     Returns or sets the sphere light area radius.

        :rtype: float
        """

        return self.rendering_light.SphereLightRadius

    @sphere_light_radius.setter
    def sphere_light_radius(self, value: float):
        """
        :param float value:
        """

        self.rendering_light.SphereLightRadius = value

    @property
    def type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Type() As short
                | 
                |     Returns or sets the light type.
                | 
                |         Possible light types are:
                |         1: Spot light
                |         2: Point light
                |         3: Directional light

        :rtype: int
        """

        return self.rendering_light.Type

    @type.setter
    def type(self, value: int):
        """
        :param int value:
        """

        self.rendering_light.Type = value

    def get_colour(self, o_colour: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetColor(CATSafeArrayVariant oColor)
                | 
                |     Returns the color of a light.
                |     The color is expressed with r, g, and b coefficients (between 0 and
                |     255)
                | 
                |     Parameters:
                | 
                |         oColor
                |             The color as a safe array made up of three doubles: r, g,
                |             b
                |             The array must be previously initialized.

        :param tuple o_colour:
        :rtype: None
        """
        return self.rendering_light.GetColor(o_colour)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_color'
        # # vba_code = """
        # # Public Function get_color(rendering_light)
        # #     Dim oColor (2)
        # #     rendering_light.GetColor oColor
        # #     get_color = oColor
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_origin(self, o_origin: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetOrigin(CATSafeArrayVariant oOrigin)
                | 
                |     Returns the coordinates of the origin of the light.
                |     These coordinates are set as an array of 3 Variants (double type).

        :param tuple o_origin:
        :rtype: None
        """
        return self.rendering_light.GetOrigin(o_origin)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_origin'
        # # vba_code = """
        # # Public Function get_origin(rendering_light)
        # #     Dim oOrigin (2)
        # #     rendering_light.GetOrigin oOrigin
        # #     get_origin = oOrigin
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_shadow_colour(self, o_shadow_colour: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetShadowColor(CATSafeArrayVariant oShadowColor)
                | 
                |     Returns the color of a shadow.
                |     The color is expressed with r, g, and b coefficients (between 0 and
                |     255)
                | 
                |     Parameters:
                | 
                |         oColor
                |             The color as a safe array made up of three doubles: r, g,
                |             b
                |             The array must be previously initialized.

        :param tuple o_shadow_color:
        :rtype: None
        """
        return self.rendering_light.GetShadowColor(o_shadow_colour)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_shadow_color'
        # # vba_code = """
        # # Public Function get_shadow_color(rendering_light)
        # #     Dim oShadowColor (2)
        # #     rendering_light.GetShadowColor oShadowColor
        # #     get_shadow_color = oShadowColor
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_target(self, o_target: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetTarget(CATSafeArrayVariant oTarget)
                | 
                |     Returns the coordinates of the target point of the light.
                |     These coordinates are set as an array of 3 Variants (double type).

        :param tuple o_target:
        :rtype: None
        """
        return self.rendering_light.GetTarget(o_target)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_target'
        # # vba_code = """
        # # Public Function get_target(rendering_light)
        # #     Dim oTarget (2)
        # #     rendering_light.GetTarget oTarget
        # #     get_target = oTarget
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def put_colour(self, i_colour: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub PutColor(CATSafeArrayVariant iColor)
                | 
                |     Sets the color of a light.
                |     The color is expressed with r, g, and b coefficients (between 0 and
                |     255)

        :param tuple i_colour:
        :rtype: None
        """
        return self.rendering_light.PutColor(i_colour)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'put_color'
        # # vba_code = """
        # # Public Function put_color(rendering_light)
        # #     Dim iColor (2)
        # #     rendering_light.PutColor iColor
        # #     put_color = iColor
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def put_origin(self, i_origin: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub PutOrigin(CATSafeArrayVariant iOrigin)
                | 
                |     Sets the coordinates of the origin of the light.
                |     These coordinates are set as an array of 3 Variants (double
                |     type).
                | 
                |     Example:
                |         This example sets the origin of the MyLight light. to the point with
                |         coordinates (10, 25, 15).
                | 
                |          MyLight.PutOrigin Array(10, 25, 15)

        :param tuple i_origin:
        :rtype: None
        """
        return self.rendering_light.PutOrigin(i_origin)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'put_origin'
        # # vba_code = """
        # # Public Function put_origin(rendering_light)
        # #     Dim iOrigin (2)
        # #     rendering_light.PutOrigin iOrigin
        # #     put_origin = iOrigin
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def put_shadow_colour(self, i_shadow_colour: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub PutShadowColor(CATSafeArrayVariant iShadowColor)
                | 
                |     Sets the color of a shadow.
                |     The color is expressed with r, g, and b coefficients (between 0 and
                |     255)

        :param tuple i_shadow_color:
        :rtype: None
        """
        return self.rendering_light.PutShadowColor(i_shadow_colour)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'put_shadow_color'
        # # vba_code = """
        # # Public Function put_shadow_color(rendering_light)
        # #     Dim iShadowColor (2)
        # #     rendering_light.PutShadowColor iShadowColor
        # #     put_shadow_color = iShadowColor
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def put_target(self, i_target: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub PutTarget(CATSafeArrayVariant iTarget)
                | 
                |     Sets the coordinates of the target point of the light.
                |     These coordinates are set as an array of 3 Variants (double type).

        :param tuple i_target:
        :rtype: None
        """
        return self.rendering_light.PutTarget(i_target)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'put_target'
        # # vba_code = """
        # # Public Function put_target(rendering_light)
        # #     Dim iTarget (2)
        # #     rendering_light.PutTarget iTarget
        # #     put_target = iTarget
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'RenderingLight(name="{self.name}")'
